.. rst-class:: detail

GetRobtarget
=======================

.. currentmodule:: compas_rrc

.. autoclass:: GetRobtarget

    
    
    .. rubric:: Methods

    .. autosummary::
        :toctree:

    
        ~GetRobtarget.__init__
        ~GetRobtarget.from_msg
        ~GetRobtarget.parse_feedback
    
    